# qgear


<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

``` sh
# make sure GRADIENT_IMAGE package is installed in development mode
$ pip3 install -e '.[dev]'

# make changes under nbs/ directory
# ...

# compile to have changes apply to GRADIENT_IMAGE
$ nbdev_prepare
```
